# numerical-collection-py

A collection of algorithms in numerical analysis for Python (originally implemented in C++).

![PyPI](https://img.shields.io/pypi/v/numerical-collection-py)
![PyPI - License](https://img.shields.io/pypi/l/numerical-collection-py)
[![pipeline status](https://gitlab.com/MusicScience37Projects/numerical-analysis/numerical-collection-py/badges/develop/pipeline.svg)](https://gitlab.com/MusicScience37Projects/numerical-analysis/numerical-collection-py/-/commits/develop)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![coverage report](https://gitlab.com/MusicScience37Projects/numerical-analysis/numerical-collection-py/badges/develop/coverage.svg)](https://gitlab.com/MusicScience37Projects/numerical-analysis/numerical-collection-py/-/commits/develop)

## Repositories

- Main in GitLab: [https://gitlab.com/MusicScience37Projects/numerical-analysis/numerical-collection-py](https://gitlab.com/MusicScience37Projects/numerical-analysis/numerical-collection-py)

## Documentation

- [Documentation built on develop branch](https://musicscience37projects.gitlab.io/numerical-analysis/numerical-collection-py/)
